==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamedInstallStrategyBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy,io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyBuilder>{
  public NamedInstallStrategyBuilder() {
    this(false);
  }
  public NamedInstallStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new NamedInstallStrategy(), validationEnabled);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamedInstallStrategy(), validationEnabled);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance) {
    this(fluent, instance, false);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStrategy(instance.getStrategy()); 
    this.validationEnabled = validationEnabled; 
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance) {
    this(instance,false);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSpec(instance.getSpec()); 
    this.withStrategy(instance.getStrategy()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy build() {
    NamedInstallStrategy buildable = new NamedInstallStrategy(fluent.getSpec(),fluent.getStrategy());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedInstallStrategyBuilder that = (NamedInstallStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.4-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamedInstallStrategyBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy,io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyBuilder>{
  public NamedInstallStrategyBuilder() {
    this(false);
  }
  public NamedInstallStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new NamedInstallStrategy(), validationEnabled);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamedInstallStrategy(), validationEnabled);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance) {
    this(fluent, instance, false);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStrategy(instance.getStrategy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance) {
    this(instance,false);
  }
  public NamedInstallStrategyBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSpec(instance.getSpec()); 
    this.withStrategy(instance.getStrategy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.NamedInstallStrategy build() {
    NamedInstallStrategy buildable = new NamedInstallStrategy(fluent.getSpec(),fluent.getStrategy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedInstallStrategyBuilder that = (NamedInstallStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
